% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/biblioNetwork.R
\name{biblioNetwork}
\alias{biblioNetwork}
\title{Creating Bibliographic networks}
\usage{
biblioNetwork(M, analysis = "coupling", network = "authors", sep = ";")
}
\arguments{
\item{M}{is a bibliographic data frame obtained by the converting function
\code{\link{convert2df}}. It is a data matrix with cases corresponding to
manuscripts and variables to Field Tag in the original SCOPUS and Thomson Reuters' ISI Web of Knowledge file.}

\item{analysis}{is a character object. It indicates the type of analysis have to be performed.
\code{analysis} argument can be \code{"collaboration"}, \code{"coupling"} or \code{"co-citation"}.
Default is \code{analysis = "coupling"}.}

\item{network}{is a character object. It indicates the network typology. The \code{network} aurgument can be
\code{"authors"}, \code{"references"}, \code{"sources"}, \code{"countries"},\code{"keywords"} or \code{"author_keywords"}.
Default is \code{network = "authors"}.}

\item{sep}{is the field separator character. This character separates strings in each column of the data frame. The default is \code{sep = ";"}.}
}
\value{
It is a squared network matrix. It is an object of class \code{dgMatrix} of the package \code{\link{Matrix}}.
}
\description{
\code{biblioNetwork} creates different bibliographic networks from a bibliographic data frame.
}
\details{
The function \code{\link{biblioNetwork}} can create a collection of bibliographic networks following the approach proposed by Batagely and Cerinsek (2013).\cr\cr
Typical networks output of \code{biblioNetwork} are:\cr\cr
#### Collaboration Networks ############\cr
-- Authors collaboration (analysis = "collaboration", network = "authors")\cr
-- Country collabortion (analysis = "collaboration", network = "countries")\cr\cr
#### Co-citation Networks ##############\cr
-- Authors co-citation (analysis = "co-citation", network = "authors")\cr
-- Reference co-citation (analysis = "co-citation", network = "references")\cr
-- Source co-citation (analysis = "co-citation", network = "sources")\cr\cr
#### Coupling Networks ################\cr
-- Manuscript coupling (analysis = "coupling", network = "references")\cr
-- Authors coupling (analysis = "coupling", network = "authors")\cr
-- Source coupling (analysis = "coupling", network = "sources")\cr
-- Keyword coupling (analysis = "coupling", network = "keywords")\cr
-- Author-Keyword coupling (analysis = "coupling", network = "author_keywords")\cr
-- Country coupling (analysis = "coupling", network = "countries")\cr\cr
}
\examples{
# EXAMPLE 1: Authors collaboration network

library(igraph)
data(scientometrics)

NetMatrix <- biblioNetwork(scientometrics, analysis = "collaboration", 
network = "authors", sep = ";")
netDegree <- 2
diag <- Matrix::diag 
NetMatrix <- NetMatrix[diag(NetMatrix) >= netDegree,diag(NetMatrix) >= netDegree]
diag(NetMatrix) <- 0

bsk.network <- graph.adjacency(NetMatrix,mode = "undirected")
plot(bsk.network,layout = layout.fruchterman.reingold, vertex.label.dist = 0.5,
vertex.frame.color = 'blue', vertex.label.color = 'black',
vertex.label.font = 1, vertex.label = V(bsk.network)$name, vertex.label.cex = 0.7)


# EXAMPLE 2: Co-citation network

library(igraph)
data(scientometrics)

NetMatrix <- biblioNetwork(scientometrics, analysis = "co-citation", 
network = "references", sep = ";")
netDegree=10
diag <- Matrix::diag
NetMatrix <- NetMatrix[diag(NetMatrix) >= netDegree,diag(NetMatrix) >= netDegree]
diag(NetMatrix) <- 0

bsk.network <- graph.adjacency(NetMatrix,mode = "undirected")
plot(bsk.network,layout = layout.fruchterman.reingold, vertex.label.dist = 0.5,
vertex.frame.color = 'blue', vertex.label.color = 'black',
vertex.label.font = 1, vertex.label = V(bsk.network)$name, vertex.label.cex = 0.7)

}
\seealso{
\code{\link{convert2df}} to import and convert a SCOPUS and Thomson 
  Reuters' ISI Web of Knowledge export file in a data frame.

\code{\link{cocMatrix}} to compute a co-occurrence matrix.

\code{\link{biblioAnalysis}} to perform a bibliometric analysis.
}

